@@ -2,14 +2,17 @@ package RapidApp;
 use strict;
 use warnings;
 
-our $VERSION = '0.99203';
-
-use Carp::Clan;
+our $VERSION = '0.99300';
 
 # ABSTRACT: Turnkey ajaxy webapps
 
+use Carp::Clan;
+use Time::HiRes qw(gettimeofday);
 use File::ShareDir qw(dist_dir);
 
+# For statistics:
+our $START = [gettimeofday];
+
 sub share_dir {
   my $class = shift || __PACKAGE__;
   return $ENV{RAPIDAPP_SHARE_DIR} || dist_dir($class);
